/****************************************************************************
** Meta object code from reading C++ file 'framesvgitem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../ksvg-6.29.0/src/declarativeimports/framesvgitem.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'framesvgitem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4KSvg19FrameSvgItemMarginsE_t {};
} // unnamed namespace

template <> constexpr inline auto KSvg::FrameSvgItemMargins::qt_create_metaobjectdata<qt_meta_tag_ZN4KSvg19FrameSvgItemMarginsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSvg::FrameSvgItemMargins",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "FrameSvgItemMargins are read-only properties of FrameSvgItem",
        "marginsChanged",
        "",
        "update",
        "left",
        "top",
        "right",
        "bottom",
        "horizontal",
        "vertical"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'marginsChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'update'
        QtMocHelpers::SlotData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'left'
        QtMocHelpers::PropertyData<qreal>(10, QMetaType::QReal, QMC::DefaultPropertyFlags, 0),
        // property 'top'
        QtMocHelpers::PropertyData<qreal>(11, QMetaType::QReal, QMC::DefaultPropertyFlags, 0),
        // property 'right'
        QtMocHelpers::PropertyData<qreal>(12, QMetaType::QReal, QMC::DefaultPropertyFlags, 0),
        // property 'bottom'
        QtMocHelpers::PropertyData<qreal>(13, QMetaType::QReal, QMC::DefaultPropertyFlags, 0),
        // property 'horizontal'
        QtMocHelpers::PropertyData<qreal>(14, QMetaType::QReal, QMC::DefaultPropertyFlags, 0),
        // property 'vertical'
        QtMocHelpers::PropertyData<qreal>(15, QMetaType::QReal, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<FrameSvgItemMargins, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KSvg::FrameSvgItemMargins::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KSvg19FrameSvgItemMarginsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KSvg19FrameSvgItemMarginsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4KSvg19FrameSvgItemMarginsE_t>.metaTypes,
    nullptr
} };

void KSvg::FrameSvgItemMargins::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FrameSvgItemMargins *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->marginsChanged(); break;
        case 1: _t->update(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FrameSvgItemMargins::*)()>(_a, &FrameSvgItemMargins::marginsChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->left(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->top(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->right(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->bottom(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->horizontal(); break;
        case 5: *reinterpret_cast<qreal*>(_v) = _t->vertical(); break;
        default: break;
        }
    }
}

const QMetaObject *KSvg::FrameSvgItemMargins::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSvg::FrameSvgItemMargins::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KSvg19FrameSvgItemMarginsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KSvg::FrameSvgItemMargins::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void KSvg::FrameSvgItemMargins::marginsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN4KSvg12FrameSvgItemE_t {};
} // unnamed namespace

template <> constexpr inline auto KSvg::FrameSvgItem::qt_create_metaobjectdata<qt_meta_tag_ZN4KSvg12FrameSvgItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSvg::FrameSvgItem",
        "QML.Element",
        "auto",
        "imagePathChanged",
        "",
        "prefixChanged",
        "enabledBordersChanged",
        "fromCurrentImageSetChanged",
        "repaintNeeded",
        "statusChanged",
        "usedPrefixChanged",
        "maskChanged",
        "doUpdate",
        "hasElementPrefix",
        "prefix",
        "hasElement",
        "elementName",
        "imagePath",
        "QVariant",
        "usedPrefix",
        "margins",
        "KSvg::FrameSvgItemMargins*",
        "fixedMargins",
        "inset",
        "enabledBorders",
        "KSvg::FrameSvg::EnabledBorders",
        "fromCurrentImageSet",
        "status",
        "KSvg::Svg::Status",
        "mask",
        "QRegion",
        "minimumDrawingHeight",
        "minimumDrawingWidth"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'imagePathChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'prefixChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledBordersChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fromCurrentImageSetChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'repaintNeeded'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'usedPrefixChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maskChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'doUpdate'
        QtMocHelpers::SlotData<void()>(12, 4, QMC::AccessPrivate, QMetaType::Void),
        // Method 'hasElementPrefix'
        QtMocHelpers::MethodData<bool(const QString &) const>(13, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 14 },
        }}),
        // Method 'hasElement'
        QtMocHelpers::MethodData<bool(const QString &) const>(15, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'imagePath'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'prefix'
        QtMocHelpers::PropertyData<QVariant>(14, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'usedPrefix'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'margins'
        QtMocHelpers::PropertyData<KSvg::FrameSvgItemMargins*>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'fixedMargins'
        QtMocHelpers::PropertyData<KSvg::FrameSvgItemMargins*>(22, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'inset'
        QtMocHelpers::PropertyData<KSvg::FrameSvgItemMargins*>(23, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'enabledBorders'
        QtMocHelpers::PropertyData<KSvg::FrameSvg::EnabledBorders>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'fromCurrentImageSet'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'status'
        QtMocHelpers::PropertyData<KSvg::Svg::Status>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'mask'
        QtMocHelpers::PropertyData<QRegion>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
        // property 'minimumDrawingHeight'
        QtMocHelpers::PropertyData<int>(31, QMetaType::Int, QMC::DefaultPropertyFlags, 4),
        // property 'minimumDrawingWidth'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<FrameSvgItem, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN4KSvg12FrameSvgItemE[] = {
    QMetaObject::SuperData::link<KSvg::FrameSvg::staticMetaObject>(),
    QMetaObject::SuperData::link<KSvg::Svg::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject KSvg::FrameSvgItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KSvg12FrameSvgItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KSvg12FrameSvgItemE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN4KSvg12FrameSvgItemE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4KSvg12FrameSvgItemE_t>.metaTypes,
    nullptr
} };

void KSvg::FrameSvgItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FrameSvgItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->imagePathChanged(); break;
        case 1: _t->prefixChanged(); break;
        case 2: _t->enabledBordersChanged(); break;
        case 3: _t->fromCurrentImageSetChanged(); break;
        case 4: _t->repaintNeeded(); break;
        case 5: _t->statusChanged(); break;
        case 6: _t->usedPrefixChanged(); break;
        case 7: _t->maskChanged(); break;
        case 8: _t->doUpdate(); break;
        case 9: { bool _r = _t->hasElementPrefix((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->hasElement((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FrameSvgItem::*)()>(_a, &FrameSvgItem::imagePathChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FrameSvgItem::*)()>(_a, &FrameSvgItem::prefixChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FrameSvgItem::*)()>(_a, &FrameSvgItem::enabledBordersChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FrameSvgItem::*)()>(_a, &FrameSvgItem::fromCurrentImageSetChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FrameSvgItem::*)()>(_a, &FrameSvgItem::repaintNeeded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FrameSvgItem::*)()>(_a, &FrameSvgItem::statusChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FrameSvgItem::*)()>(_a, &FrameSvgItem::usedPrefixChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FrameSvgItem::*)()>(_a, &FrameSvgItem::maskChanged, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
        case 4:
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KSvg::FrameSvgItemMargins* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->imagePath(); break;
        case 1: *reinterpret_cast<QVariant*>(_v) = _t->prefix(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->usedPrefix(); break;
        case 3: *reinterpret_cast<KSvg::FrameSvgItemMargins**>(_v) = _t->margins(); break;
        case 4: *reinterpret_cast<KSvg::FrameSvgItemMargins**>(_v) = _t->fixedMargins(); break;
        case 5: *reinterpret_cast<KSvg::FrameSvgItemMargins**>(_v) = _t->inset(); break;
        case 6: *reinterpret_cast<KSvg::FrameSvg::EnabledBorders*>(_v) = _t->enabledBorders(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->fromCurrentImageSet(); break;
        case 8: *reinterpret_cast<KSvg::Svg::Status*>(_v) = _t->status(); break;
        case 9: *reinterpret_cast<QRegion*>(_v) = _t->mask(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->minimumDrawingHeight(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->minimumDrawingWidth(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setImagePath(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setPrefix(*reinterpret_cast<QVariant*>(_v)); break;
        case 6: _t->setEnabledBorders(*reinterpret_cast<KSvg::FrameSvg::EnabledBorders*>(_v)); break;
        case 8: _t->setStatus(*reinterpret_cast<KSvg::Svg::Status*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KSvg::FrameSvgItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSvg::FrameSvgItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KSvg12FrameSvgItemE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int KSvg::FrameSvgItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void KSvg::FrameSvgItem::imagePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KSvg::FrameSvgItem::prefixChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KSvg::FrameSvgItem::enabledBordersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KSvg::FrameSvgItem::fromCurrentImageSetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KSvg::FrameSvgItem::repaintNeeded()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KSvg::FrameSvgItem::statusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KSvg::FrameSvgItem::usedPrefixChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KSvg::FrameSvgItem::maskChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
