/****************************************************************************
** Meta object code from reading C++ file 'svg.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../ksvg-6.29.0/src/ksvg/svg.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'svg.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4KSvg3SvgE_t {};
} // unnamed namespace

template <> constexpr inline auto KSvg::Svg::qt_create_metaobjectdata<qt_meta_tag_ZN4KSvg3SvgE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSvg::Svg",
        "repaintNeeded",
        "",
        "sizeChanged",
        "imagePathChanged",
        "colorHintChanged",
        "fromCurrentImageSetChanged",
        "fromCurrentImageSet",
        "statusChanged",
        "KSvg::Svg::Status",
        "status",
        "colorSetChanged",
        "KSvg::Svg::ColorSet",
        "colorSet",
        "imageSetChanged",
        "ImageSet*",
        "imageSet",
        "colorsChanged",
        "pixmap",
        "QPixmap",
        "elementID",
        "image",
        "QImage",
        "QSize",
        "size",
        "paint",
        "QPainter*",
        "painter",
        "QPointF",
        "point",
        "x",
        "y",
        "QRectF",
        "rect",
        "width",
        "height",
        "resize",
        "QSizeF",
        "elementSize",
        "elementId",
        "elementRect",
        "hasElement",
        "isValid",
        "multipleImages",
        "imagePath",
        "usingRenderingCache",
        "Status",
        "Normal",
        "Selected",
        "Inactive",
        "ColorSet",
        "View",
        "Window",
        "Button",
        "Selection",
        "Tooltip",
        "Complementary",
        "Header",
        "StyleSheetColor",
        "Text",
        "Background",
        "Highlight",
        "HighlightedText",
        "PositiveText",
        "NeutralText",
        "NegativeText",
        "ButtonText",
        "ButtonBackground",
        "ButtonHover",
        "ButtonFocus",
        "ButtonHighlightedText",
        "ButtonPositiveText",
        "ButtonNeutralText",
        "ButtonNegativeText",
        "ViewText",
        "ViewBackground",
        "ViewHover",
        "ViewFocus",
        "ViewHighlightedText",
        "ViewPositiveText",
        "ViewNeutralText",
        "ViewNegativeText",
        "TooltipText",
        "TooltipBackground",
        "TooltipHover",
        "TooltipFocus",
        "TooltipHighlightedText",
        "TooltipPositiveText",
        "TooltipNeutralText",
        "TooltipNegativeText",
        "ComplementaryText",
        "ComplementaryBackground",
        "ComplementaryHover",
        "ComplementaryFocus",
        "ComplementaryHighlightedText",
        "ComplementaryPositiveText",
        "ComplementaryNeutralText",
        "ComplementaryNegativeText",
        "HeaderText",
        "HeaderBackground",
        "HeaderHover",
        "HeaderFocus",
        "HeaderHighlightedText",
        "HeaderPositiveText",
        "HeaderNeutralText",
        "HeaderNegativeText",
        "Frame"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'repaintNeeded'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sizeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imagePathChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorHintChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fromCurrentImageSetChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(KSvg::Svg::Status)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'colorSetChanged'
        QtMocHelpers::SignalData<void(KSvg::Svg::ColorSet)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'imageSetChanged'
        QtMocHelpers::SignalData<void(ImageSet *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'imageSetChanged'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'colorsChanged'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'pixmap'
        QtMocHelpers::MethodData<QPixmap(const QString &)>(18, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::QString, 20 },
        }}),
        // Method 'pixmap'
        QtMocHelpers::MethodData<QPixmap()>(18, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 19),
        // Method 'image'
        QtMocHelpers::MethodData<QImage(const QSize &, const QString &)>(21, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { 0x80000000 | 23, 24 }, { QMetaType::QString, 20 },
        }}),
        // Method 'image'
        QtMocHelpers::MethodData<QImage(const QSize &)>(21, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 22, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Method 'paint'
        QtMocHelpers::MethodData<void(QPainter *, const QPointF &, const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 }, { 0x80000000 | 28, 29 }, { QMetaType::QString, 20 },
        }}),
        // Method 'paint'
        QtMocHelpers::MethodData<void(QPainter *, const QPointF &)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 26, 27 }, { 0x80000000 | 28, 29 },
        }}),
        // Method 'paint'
        QtMocHelpers::MethodData<void(QPainter *, int, int, const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 }, { QMetaType::Int, 30 }, { QMetaType::Int, 31 }, { QMetaType::QString, 20 },
        }}),
        // Method 'paint'
        QtMocHelpers::MethodData<void(QPainter *, int, int)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 26, 27 }, { QMetaType::Int, 30 }, { QMetaType::Int, 31 },
        }}),
        // Method 'paint'
        QtMocHelpers::MethodData<void(QPainter *, const QRectF &, const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 }, { 0x80000000 | 32, 33 }, { QMetaType::QString, 20 },
        }}),
        // Method 'paint'
        QtMocHelpers::MethodData<void(QPainter *, const QRectF &)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 26, 27 }, { 0x80000000 | 32, 33 },
        }}),
        // Method 'paint'
        QtMocHelpers::MethodData<void(QPainter *, int, int, int, int, const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 }, { QMetaType::Int, 30 }, { QMetaType::Int, 31 }, { QMetaType::Int, 34 },
            { QMetaType::Int, 35 }, { QMetaType::QString, 20 },
        }}),
        // Method 'paint'
        QtMocHelpers::MethodData<void(QPainter *, int, int, int, int)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 26, 27 }, { QMetaType::Int, 30 }, { QMetaType::Int, 31 }, { QMetaType::Int, 34 },
            { QMetaType::Int, 35 },
        }}),
        // Method 'resize'
        QtMocHelpers::MethodData<void(qreal, qreal)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 34 }, { QMetaType::QReal, 35 },
        }}),
        // Method 'resize'
        QtMocHelpers::MethodData<void(const QSizeF &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 24 },
        }}),
        // Method 'resize'
        QtMocHelpers::MethodData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'elementSize'
        QtMocHelpers::MethodData<QSizeF(const QString &) const>(38, 2, QMC::AccessPublic, 0x80000000 | 37, {{
            { QMetaType::QString, 39 },
        }}),
        // Method 'elementRect'
        QtMocHelpers::MethodData<QRectF(const QString &) const>(40, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::QString, 39 },
        }}),
        // Method 'hasElement'
        QtMocHelpers::MethodData<bool(const QString &) const>(41, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 39 },
        }}),
        // Method 'isValid'
        QtMocHelpers::MethodData<bool() const>(42, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'size'
        QtMocHelpers::PropertyData<QSizeF>(24, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 1),
        // property 'multipleImages'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'imagePath'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'usingRenderingCache'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'fromCurrentImageSet'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'status'
        QtMocHelpers::PropertyData<KSvg::Svg::Status>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'colorSet'
        QtMocHelpers::PropertyData<KSvg::Svg::ColorSet>(13, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(46, 46, QMC::EnumFlags{}).add({
            {   47, Status::Normal },
            {   48, Status::Selected },
            {   49, Status::Inactive },
        }),
        // enum 'ColorSet'
        QtMocHelpers::EnumData<enum ColorSet>(50, 50, QMC::EnumFlags{}).add({
            {   51, ColorSet::View },
            {   52, ColorSet::Window },
            {   53, ColorSet::Button },
            {   54, ColorSet::Selection },
            {   55, ColorSet::Tooltip },
            {   56, ColorSet::Complementary },
            {   57, ColorSet::Header },
        }),
        // enum 'StyleSheetColor'
        QtMocHelpers::EnumData<enum StyleSheetColor>(58, 58, QMC::EnumFlags{}).add({
            {   59, StyleSheetColor::Text },
            {   60, StyleSheetColor::Background },
            {   61, StyleSheetColor::Highlight },
            {   62, StyleSheetColor::HighlightedText },
            {   63, StyleSheetColor::PositiveText },
            {   64, StyleSheetColor::NeutralText },
            {   65, StyleSheetColor::NegativeText },
            {   66, StyleSheetColor::ButtonText },
            {   67, StyleSheetColor::ButtonBackground },
            {   68, StyleSheetColor::ButtonHover },
            {   69, StyleSheetColor::ButtonFocus },
            {   70, StyleSheetColor::ButtonHighlightedText },
            {   71, StyleSheetColor::ButtonPositiveText },
            {   72, StyleSheetColor::ButtonNeutralText },
            {   73, StyleSheetColor::ButtonNegativeText },
            {   74, StyleSheetColor::ViewText },
            {   75, StyleSheetColor::ViewBackground },
            {   76, StyleSheetColor::ViewHover },
            {   77, StyleSheetColor::ViewFocus },
            {   78, StyleSheetColor::ViewHighlightedText },
            {   79, StyleSheetColor::ViewPositiveText },
            {   80, StyleSheetColor::ViewNeutralText },
            {   81, StyleSheetColor::ViewNegativeText },
            {   82, StyleSheetColor::TooltipText },
            {   83, StyleSheetColor::TooltipBackground },
            {   84, StyleSheetColor::TooltipHover },
            {   85, StyleSheetColor::TooltipFocus },
            {   86, StyleSheetColor::TooltipHighlightedText },
            {   87, StyleSheetColor::TooltipPositiveText },
            {   88, StyleSheetColor::TooltipNeutralText },
            {   89, StyleSheetColor::TooltipNegativeText },
            {   90, StyleSheetColor::ComplementaryText },
            {   91, StyleSheetColor::ComplementaryBackground },
            {   92, StyleSheetColor::ComplementaryHover },
            {   93, StyleSheetColor::ComplementaryFocus },
            {   94, StyleSheetColor::ComplementaryHighlightedText },
            {   95, StyleSheetColor::ComplementaryPositiveText },
            {   96, StyleSheetColor::ComplementaryNeutralText },
            {   97, StyleSheetColor::ComplementaryNegativeText },
            {   98, StyleSheetColor::HeaderText },
            {   99, StyleSheetColor::HeaderBackground },
            {  100, StyleSheetColor::HeaderHover },
            {  101, StyleSheetColor::HeaderFocus },
            {  102, StyleSheetColor::HeaderHighlightedText },
            {  103, StyleSheetColor::HeaderPositiveText },
            {  104, StyleSheetColor::HeaderNeutralText },
            {  105, StyleSheetColor::HeaderNegativeText },
            {  106, StyleSheetColor::Frame },
        }),
    };
    return QtMocHelpers::metaObjectData<Svg, qt_meta_tag_ZN4KSvg3SvgE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KSvg::Svg::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KSvg3SvgE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KSvg3SvgE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4KSvg3SvgE_t>.metaTypes,
    nullptr
} };

void KSvg::Svg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Svg *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->repaintNeeded(); break;
        case 1: _t->sizeChanged(); break;
        case 2: _t->imagePathChanged(); break;
        case 3: _t->colorHintChanged(); break;
        case 4: _t->fromCurrentImageSetChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<KSvg::Svg::Status>>(_a[1]))); break;
        case 6: _t->colorSetChanged((*reinterpret_cast<std::add_pointer_t<KSvg::Svg::ColorSet>>(_a[1]))); break;
        case 7: _t->imageSetChanged((*reinterpret_cast<std::add_pointer_t<ImageSet*>>(_a[1]))); break;
        case 8: _t->d->imageSetChanged(); break;
        case 9: _t->d->colorsChanged(); break;
        case 10: { QPixmap _r = _t->pixmap((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QPixmap*>(_a[0]) = std::move(_r); }  break;
        case 11: { QPixmap _r = _t->pixmap();
            if (_a[0]) *reinterpret_cast<QPixmap*>(_a[0]) = std::move(_r); }  break;
        case 12: { QImage _r = _t->image((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 13: { QImage _r = _t->image((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->paint((*reinterpret_cast<std::add_pointer_t<QPainter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 15: _t->paint((*reinterpret_cast<std::add_pointer_t<QPainter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 16: _t->paint((*reinterpret_cast<std::add_pointer_t<QPainter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 17: _t->paint((*reinterpret_cast<std::add_pointer_t<QPainter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 18: _t->paint((*reinterpret_cast<std::add_pointer_t<QPainter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 19: _t->paint((*reinterpret_cast<std::add_pointer_t<QPainter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2]))); break;
        case 20: _t->paint((*reinterpret_cast<std::add_pointer_t<QPainter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 21: _t->paint((*reinterpret_cast<std::add_pointer_t<QPainter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 22: _t->resize((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 23: _t->resize((*reinterpret_cast<std::add_pointer_t<QSizeF>>(_a[1]))); break;
        case 24: _t->resize(); break;
        case 25: { QSizeF _r = _t->elementSize((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QSizeF*>(_a[0]) = std::move(_r); }  break;
        case 26: { QRectF _r = _t->elementRect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->hasElement((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->isValid();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ImageSet* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Svg::*)()>(_a, &Svg::repaintNeeded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Svg::*)()>(_a, &Svg::sizeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Svg::*)()>(_a, &Svg::imagePathChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Svg::*)()>(_a, &Svg::colorHintChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Svg::*)(bool )>(_a, &Svg::fromCurrentImageSetChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Svg::*)(KSvg::Svg::Status )>(_a, &Svg::statusChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Svg::*)(KSvg::Svg::ColorSet )>(_a, &Svg::colorSetChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Svg::*)(ImageSet * )>(_a, &Svg::imageSetChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QSizeF*>(_v) = _t->size(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->containsMultipleImages(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->imagePath(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isUsingRenderingCache(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->fromCurrentImageSet(); break;
        case 5: *reinterpret_cast<KSvg::Svg::Status*>(_v) = _t->status(); break;
        case 6: *reinterpret_cast<KSvg::Svg::ColorSet*>(_v) = _t->colorSet(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->resize(*reinterpret_cast<QSizeF*>(_v)); break;
        case 1: _t->setContainsMultipleImages(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setImagePath(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setUsingRenderingCache(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setStatus(*reinterpret_cast<KSvg::Svg::Status*>(_v)); break;
        case 6: _t->setColorSet(*reinterpret_cast<KSvg::Svg::ColorSet*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KSvg::Svg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSvg::Svg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KSvg3SvgE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KSvg::Svg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KSvg::Svg::repaintNeeded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KSvg::Svg::sizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KSvg::Svg::imagePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KSvg::Svg::colorHintChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KSvg::Svg::fromCurrentImageSetChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KSvg::Svg::statusChanged(KSvg::Svg::Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KSvg::Svg::colorSetChanged(KSvg::Svg::ColorSet _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KSvg::Svg::imageSetChanged(ImageSet * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
