/****************************************************************************
** Meta object code from reading C++ file 'framesvg.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../ksvg-6.29.0/src/ksvg/framesvg.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'framesvg.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4KSvg8FrameSvgE_t {};
} // unnamed namespace

template <> constexpr inline auto KSvg::FrameSvg::qt_create_metaobjectdata<qt_meta_tag_ZN4KSvg8FrameSvgE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSvg::FrameSvg",
        "setImagePath",
        "",
        "path",
        "resizeFrame",
        "QSizeF",
        "size",
        "frameSize",
        "marginSize",
        "FrameSvg::MarginEdge",
        "edge",
        "getMargins",
        "qreal&",
        "left",
        "top",
        "right",
        "bottom",
        "fixedMarginSize",
        "getFixedMargins",
        "insetSize",
        "getInset",
        "contentsRect",
        "QRectF",
        "setElementPrefix",
        "KSvg::FrameSvg::LocationPrefix",
        "location",
        "prefix",
        "hasElementPrefix",
        "mask",
        "QRegion",
        "setCacheAllRenderedFrames",
        "cache",
        "cacheAllRenderedFrames",
        "clearCache",
        "framePixmap",
        "QPixmap",
        "paintFrame",
        "QPainter*",
        "painter",
        "target",
        "source",
        "QPointF",
        "pos",
        "minimumDrawingHeight",
        "minimumDrawingWidth",
        "enabledBorders",
        "EnabledBorders",
        "EnabledBorder",
        "NoBorder",
        "TopBorder",
        "BottomBorder",
        "LeftBorder",
        "RightBorder",
        "AllBorders",
        "LocationPrefix",
        "Floating",
        "TopEdge",
        "BottomEdge",
        "LeftEdge",
        "RightEdge",
        "MarginEdge",
        "TopMargin",
        "BottomMargin",
        "LeftMargin",
        "RightMargin"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'setImagePath'
        QtMocHelpers::MethodData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Method 'resizeFrame'
        QtMocHelpers::MethodData<void(const QSizeF &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'frameSize'
        QtMocHelpers::MethodData<QSizeF() const>(7, 2, QMC::AccessPublic, 0x80000000 | 5),
        // Method 'marginSize'
        QtMocHelpers::MethodData<qreal(const FrameSvg::MarginEdge) const>(8, 2, QMC::AccessPublic, QMetaType::QReal, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Method 'getMargins'
        QtMocHelpers::MethodData<void(qreal &, qreal &, qreal &, qreal &) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 12, 14 }, { 0x80000000 | 12, 15 }, { 0x80000000 | 12, 16 },
        }}),
        // Method 'fixedMarginSize'
        QtMocHelpers::MethodData<qreal(const FrameSvg::MarginEdge) const>(17, 2, QMC::AccessPublic, QMetaType::QReal, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Method 'getFixedMargins'
        QtMocHelpers::MethodData<void(qreal &, qreal &, qreal &, qreal &) const>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 12, 14 }, { 0x80000000 | 12, 15 }, { 0x80000000 | 12, 16 },
        }}),
        // Method 'insetSize'
        QtMocHelpers::MethodData<qreal(const FrameSvg::MarginEdge) const>(19, 2, QMC::AccessPublic, QMetaType::QReal, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Method 'getInset'
        QtMocHelpers::MethodData<void(qreal &, qreal &, qreal &, qreal &) const>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 12, 14 }, { 0x80000000 | 12, 15 }, { 0x80000000 | 12, 16 },
        }}),
        // Method 'contentsRect'
        QtMocHelpers::MethodData<QRectF() const>(21, 2, QMC::AccessPublic, 0x80000000 | 22),
        // Method 'setElementPrefix'
        QtMocHelpers::MethodData<void(KSvg::FrameSvg::LocationPrefix)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Method 'setElementPrefix'
        QtMocHelpers::MethodData<void(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Method 'hasElementPrefix'
        QtMocHelpers::MethodData<bool(const QString &) const>(27, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 26 },
        }}),
        // Method 'hasElementPrefix'
        QtMocHelpers::MethodData<bool(KSvg::FrameSvg::LocationPrefix) const>(27, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Method 'prefix'
        QtMocHelpers::MethodData<QString()>(26, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'mask'
        QtMocHelpers::MethodData<QRegion() const>(28, 2, QMC::AccessPublic, 0x80000000 | 29),
        // Method 'setCacheAllRenderedFrames'
        QtMocHelpers::MethodData<void(bool)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Method 'cacheAllRenderedFrames'
        QtMocHelpers::MethodData<bool() const>(32, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'clearCache'
        QtMocHelpers::MethodData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'framePixmap'
        QtMocHelpers::MethodData<QPixmap()>(34, 2, QMC::AccessPublic, 0x80000000 | 35),
        // Method 'paintFrame'
        QtMocHelpers::MethodData<void(QPainter *, const QRectF &, const QRectF &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 38 }, { 0x80000000 | 22, 39 }, { 0x80000000 | 22, 40 },
        }}),
        // Method 'paintFrame'
        QtMocHelpers::MethodData<void(QPainter *, const QRectF &)>(36, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 37, 38 }, { 0x80000000 | 22, 39 },
        }}),
        // Method 'paintFrame'
        QtMocHelpers::MethodData<void(QPainter *, const QPointF &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 38 }, { 0x80000000 | 41, 42 },
        }}),
        // Method 'paintFrame'
        QtMocHelpers::MethodData<void(QPainter *)>(36, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Method 'minimumDrawingHeight'
        QtMocHelpers::MethodData<int()>(43, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'minimumDrawingWidth'
        QtMocHelpers::MethodData<int()>(44, 2, QMC::AccessPublic, QMetaType::Int),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'enabledBorders'
        QtMocHelpers::PropertyData<EnabledBorders>(45, 0x80000000 | 46, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'EnabledBorders'
        QtMocHelpers::EnumData<EnabledBorders>(46, 47, QMC::EnumIsFlag).add({
            {   48, EnabledBorder::NoBorder },
            {   49, EnabledBorder::TopBorder },
            {   50, EnabledBorder::BottomBorder },
            {   51, EnabledBorder::LeftBorder },
            {   52, EnabledBorder::RightBorder },
            {   53, EnabledBorder::AllBorders },
        }),
        // enum 'LocationPrefix'
        QtMocHelpers::EnumData<enum LocationPrefix>(54, 54, QMC::EnumFlags{}).add({
            {   55, LocationPrefix::Floating },
            {   56, LocationPrefix::TopEdge },
            {   57, LocationPrefix::BottomEdge },
            {   58, LocationPrefix::LeftEdge },
            {   59, LocationPrefix::RightEdge },
        }),
        // enum 'MarginEdge'
        QtMocHelpers::EnumData<enum MarginEdge>(60, 60, QMC::EnumFlags{}).add({
            {   61, MarginEdge::TopMargin },
            {   62, MarginEdge::BottomMargin },
            {   63, MarginEdge::LeftMargin },
            {   64, MarginEdge::RightMargin },
        }),
    };
    return QtMocHelpers::metaObjectData<FrameSvg, qt_meta_tag_ZN4KSvg8FrameSvgE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KSvg::FrameSvg::staticMetaObject = { {
    QMetaObject::SuperData::link<Svg::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KSvg8FrameSvgE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KSvg8FrameSvgE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4KSvg8FrameSvgE_t>.metaTypes,
    nullptr
} };

void KSvg::FrameSvg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FrameSvg *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setImagePath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->resizeFrame((*reinterpret_cast<std::add_pointer_t<QSizeF>>(_a[1]))); break;
        case 2: { QSizeF _r = _t->frameSize();
            if (_a[0]) *reinterpret_cast<QSizeF*>(_a[0]) = std::move(_r); }  break;
        case 3: { qreal _r = _t->marginSize((*reinterpret_cast<std::add_pointer_t<FrameSvg::MarginEdge>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->getMargins((*reinterpret_cast<std::add_pointer_t<qreal&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal&>>(_a[4]))); break;
        case 5: { qreal _r = _t->fixedMarginSize((*reinterpret_cast<std::add_pointer_t<FrameSvg::MarginEdge>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->getFixedMargins((*reinterpret_cast<std::add_pointer_t<qreal&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal&>>(_a[4]))); break;
        case 7: { qreal _r = _t->insetSize((*reinterpret_cast<std::add_pointer_t<FrameSvg::MarginEdge>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->getInset((*reinterpret_cast<std::add_pointer_t<qreal&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal&>>(_a[4]))); break;
        case 9: { QRectF _r = _t->contentsRect();
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setElementPrefix((*reinterpret_cast<std::add_pointer_t<KSvg::FrameSvg::LocationPrefix>>(_a[1]))); break;
        case 11: _t->setElementPrefix((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: { bool _r = _t->hasElementPrefix((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->hasElementPrefix((*reinterpret_cast<std::add_pointer_t<KSvg::FrameSvg::LocationPrefix>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { QString _r = _t->prefix();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { QRegion _r = _t->mask();
            if (_a[0]) *reinterpret_cast<QRegion*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->setCacheAllRenderedFrames((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: { bool _r = _t->cacheAllRenderedFrames();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->clearCache(); break;
        case 19: { QPixmap _r = _t->framePixmap();
            if (_a[0]) *reinterpret_cast<QPixmap*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->paintFrame((*reinterpret_cast<std::add_pointer_t<QPainter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[3]))); break;
        case 21: _t->paintFrame((*reinterpret_cast<std::add_pointer_t<QPainter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2]))); break;
        case 22: _t->paintFrame((*reinterpret_cast<std::add_pointer_t<QPainter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 23: _t->paintFrame((*reinterpret_cast<std::add_pointer_t<QPainter*>>(_a[1]))); break;
        case 24: { int _r = _t->minimumDrawingHeight();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 25: { int _r = _t->minimumDrawingWidth();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::assignFlags<EnabledBorders>(_v, _t->enabledBorders()); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setEnabledBorders(*reinterpret_cast<EnabledBorders*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KSvg::FrameSvg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSvg::FrameSvg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KSvg8FrameSvgE_t>.strings))
        return static_cast<void*>(this);
    return Svg::qt_metacast(_clname);
}

int KSvg::FrameSvg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Svg::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
