/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<framesvgitem.h>)
#  include <framesvgitem.h>
#endif
#if __has_include(<svgitem.h>)
#  include <svgitem.h>
#endif
#if __has_include(<types.h>)
#  include <types.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_ksvg()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<FrameSvgForeign>("org.kde.ksvg", 1);
    qmlRegisterEnum<KSvg::FrameSvg::EnabledBorders>("KSvg::FrameSvg::EnabledBorders");
    qmlRegisterEnum<KSvg::FrameSvg::EnabledBorder>("KSvg::FrameSvg::EnabledBorder");
    qmlRegisterEnum<KSvg::FrameSvg::LocationPrefix>("KSvg::FrameSvg::LocationPrefix");
    qmlRegisterEnum<KSvg::FrameSvg::MarginEdge>("KSvg::FrameSvg::MarginEdge");
    qmlRegisterTypesAndRevisions<ImageSetForeign>("org.kde.ksvg", 1);
    qmlRegisterTypesAndRevisions<KSvg::FrameSvgItem>("org.kde.ksvg", 1);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.kde.ksvg", 1);
    qmlRegisterTypesAndRevisions<KSvg::FrameSvgItemMargins>("org.kde.ksvg", 1);
    qmlRegisterTypesAndRevisions<KSvg::SvgItem>("org.kde.ksvg", 1);
    qmlRegisterTypesAndRevisions<PlatformThemeForeign>("org.kde.ksvg", 1);
    qmlRegisterEnum<Kirigami::Platform::PlatformTheme::ColorSet>("Kirigami::Platform::PlatformTheme::ColorSet");
    qmlRegisterEnum<Kirigami::Platform::PlatformTheme::ColorGroup>("Kirigami::Platform::PlatformTheme::ColorGroup");
    qmlRegisterTypesAndRevisions<SvgForeign>("org.kde.ksvg", 1);
    qmlRegisterEnum<KSvg::Svg::Status>("KSvg::Svg::Status");
    qmlRegisterEnum<KSvg::Svg::ColorSet>("KSvg::Svg::ColorSet");
    qmlRegisterEnum<KSvg::Svg::StyleSheetColor>("KSvg::Svg::StyleSheetColor");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.ksvg", 1, 0);
}

static const QQmlModuleRegistration orgkdeksvgRegistration("org.kde.ksvg", qml_register_types_org_kde_ksvg);
